@@ -3,7 +3,6 @@
 #ifndef ECAP__ADAPTER_XACTION_H
 #define ECAP__ADAPTER_XACTION_H
 
-#include <libecap/common/call.h>
 #include <libecap/common/area.h>
 #include <libecap/common/options.h>
 
@@ -13,13 +12,14 @@ namespace adapter {
 // adapter transaction is responsible for adapting a single message
 // it is created by adapter::Service::makeXaction and destroyed by
 // the host either before calling start() or after calling stop()
-class Xaction: public Callable, public Options {
+class Xaction: public Options {
 	public:
 		virtual ~Xaction() {}
 
 		// lifecycle
 		virtual void start() = 0;
 		virtual void stop() = 0;
+		virtual void resume();
 
 		// adapted body transmission control
 		virtual void abDiscard() = 0; // host will not look at ab at all
